package
module
Version:
v0.0.2
Opens a new window with list of versions in this module.
Published: Aug 8, 2021
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
Documentation
¶
type Database struct {
Connection string `json:"Connection"`
DB string `json:"dbType"`
Description string `json:"Description"`
ConnectString string `json:"ConnectString"`
CMD_ConnectString string `json:"CMD_ConnectString"`
}
type Databases struct {
Databases []Database `json:"Databases"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.